AssistantMessage

Struct AssistantMessage 

pub struct AssistantMessage {
    pub id: String,
    pub message_type: String,
    pub role: MessageRole,
    pub content: Vec<ContentBlock>,
    pub model: String,
    pub stop_reason: StopReason,
    pub created_at: String,
    pub usage: Usage,
    pub cache_usage: CacheUsage,
    pub parent_tool_use_id: Option<String>,
    pub error: Option<AssistantMessageError>,
}
An assistant message in a conversation

Fields

id: String

Unique identifier for the message

message_type: String

Type of message (always “message”)

role: MessageRole

The role (always “assistant”)

content: Vec<ContentBlock>

The content blocks in the message

model: String

The model used to generate this message

stop_reason: StopReason

Why the model stopped generating

created_at: String

When the message was created

usage: Usage

Token usage information

cache_usage: CacheUsage

Cache usage information

parent_tool_use_id: Option<String>

Parent tool use ID for messages in tool execution context

error: Option<AssistantMessageError>

Error type if the message generation failed.

When this is set, the message may be incomplete or contain error information.

Implementations

Source

impl AssistantMessage

pub fn new( model: impl Into<String>, content: Vec<ContentBlock>, usage: Usage, ) -> Self

Create a new assistant message

pub fn with_error( model: impl Into<String>, content: Vec<ContentBlock>, usage: Usage, error: AssistantMessageError, ) -> Self

Create an error message with the specified error type.

pub fn set_parent_tool_use_id(self, id: impl Into<String>) -> Self

Set the parent tool use ID.

pub fn has_error(&self) -> bool

Check if this message has an error.

pub fn is_retryable(&self) -> bool

Check if this message’s error is retryable.